fn need_to_unconditionally_recascade_for_reset_change(
old_values: &ComputedValues,
new_values: &ComputedValues,
) -> boolExpand description
Whether we need to recascade children for a change in non-inherited properties.
fn need_to_unconditionally_recascade_for_reset_change(
old_values: &ComputedValues,
new_values: &ComputedValues,
) -> boolWhether we need to recascade children for a change in non-inherited properties.